@@ -29,13 +29,17 @@ version_GEOS0 <- function() {
   set_RGEOS_HANDLE(init_RGEOS())
   assign("scale", 100000000, envir=.RGEOS_HANDLE)
   assign("do_poly_check", TRUE, envir=.RGEOS_HANDLE)
+
+}
+
+.onAttach <- function(lib, pkg) {
   fn <- system.file("SVN_VERSION", package="rgeos")
   if (file.exists(fn)) {
     svn_version <- scan(fn, what=character(1), sep="\n", quiet=TRUE)
   } else {
     svn_version <- "(unknown)"
   }
-  Smess <- paste("rgeos version: ", utils::packageVersion("rgeos"),
+  Smess <- paste("rgeos version: ", utils::packageDescription("rgeos")$Version,
     ", (SVN revision ", svn_version, ")\n", sep="")
   Smess <- paste(Smess, "GEOS runtime version:",
     version_GEOS(), "\n")
